@@ -1,7 +1,7 @@
 from django.db import models
 from django.template.loader import render_to_string
 
-from models import Article
+from .models import Article
 
 
 class ArticleList(models.Model):
