@@ -1,4 +1,4 @@
-from django.conf.urls.defaults import patterns, url
+from django.conf.urls import patterns, url
 from django.core.exceptions import ImproperlyConfigured
 from django.utils.translation import ugettext_lazy as _
 from feincms import extensions
@@ -6,7 +6,7 @@ from feincms import extensions
 try:
     from taggit.managers import TaggableManager
 except ImportError:
-   raise ImproperlyConfigured('You need to install django-taggit to use the tags extension')
+    raise ImproperlyConfigured('You need to install django-taggit to use the tags extension')
 
 
 class Extension(extensions.Extension):
